@@ -7,7 +7,7 @@ import configparser
 from optparse import OptionParser
 from nose.util import absdir, tolist
 from nose.plugins.manager import NoPlugins
-from warnings import warn
+from warnings import warn, filterwarnings
 
 log = logging.getLogger(__name__)
 
@@ -25,6 +25,8 @@ config_files = [
 # Windows and IronPython
 exe_allowed_platforms = ('win32', 'cli')
 
+filterwarnings("always", category=DeprecationWarning,
+               module=r'(.*\.)?nose\.config')
 
 class NoSuchOptionError(Exception):
     def __init__(self, name):
@@ -129,7 +131,10 @@ class ConfiguredDefaultsOptionParser(object):
         except ConfigError as exc:
             self._error(str(exc))
         else:
-            self._applyConfigurationToValues(self._parser, config, values)
+            try:
+                self._applyConfigurationToValues(self._parser, config, values)
+            except ConfigError as exc:
+                self._error(str(exc))
         return self._parser.parse_args(args, values)
 
 
@@ -169,7 +174,7 @@ class Config(object):
       self.verbosity = int(env.get('NOSE_VERBOSE', 1))
       self.where = ()
       self.py3where = ()
-      self.workingDir = None   
+      self.workingDir = None
     """
 
     def __init__(self, **kw):
@@ -210,7 +215,7 @@ class Config(object):
         self.firstPackageWins = False
         self.parserClass = OptionParser
         self.worker = False
-        
+
         self._default = self.__dict__.copy()
         self.update(kw)
         self._orig = self.__dict__.copy()
@@ -237,7 +242,7 @@ class Config(object):
         dummy_parser = self.parserClass()
         self.plugins.addOptions(dummy_parser, {})
         self.plugins.configure(self.options, self)
-    
+
     def __repr__(self):
         d = self.__dict__.copy()
         # don't expose env, could include sensitive info
@@ -289,7 +294,7 @@ class Config(object):
             if sys.version_info >= (3,):
                 options.where = options.py3where
 
-        # `where` is an append action, so it can't have a default value 
+        # `where` is an append action, so it can't have a default value
         # in the parser, or that default will always be in the list
         if not options.where:
             options.where = env.get('NOSE_WHERE', None)
@@ -313,18 +318,21 @@ class Config(object):
         self.firstPackageWins = options.firstPackageWins
         self.configureLogging()
 
+        if not options.byteCompile:
+            sys.dont_write_bytecode = True
+
         if options.where is not None:
             self.configureWhere(options.where)
-        
+
         if options.testMatch:
             self.testMatch = re.compile(options.testMatch)
-        
+
         if options.ignoreFiles:
             self.ignoreFiles = list(map(re.compile, tolist(options.ignoreFiles)))
             log.info("Ignoring files matching %s", options.ignoreFiles)
         else:
             log.info("Ignoring files matching %s", self.ignoreFilesDefaultStrings)
-        
+
         if options.include:
             self.include = list(map(re.compile, tolist(options.include)))
             log.info("Including tests matching %s", options.include)
@@ -348,7 +356,7 @@ class Config(object):
             from logging.config import fileConfig
             fileConfig(self.loggingConfig)
             return
-        
+
         format = logging.Formatter('%(name)s: %(levelname)s: %(message)s')
         if self.debugLog:
             handler = logging.FileHandler(self.debugLog)
@@ -361,10 +369,22 @@ class Config(object):
 
         # only add our default handler if there isn't already one there
         # this avoids annoying duplicate log messages.
-        if handler not in logger.handlers:
+        found = False
+        if self.debugLog:
+            debugLogAbsPath = os.path.abspath(self.debugLog)
+            for h in logger.handlers:
+                if type(h) == logging.FileHandler and \
+                        h.baseFilename == debugLogAbsPath:
+                    found = True
+        else:
+            for h in logger.handlers:
+                if type(h) == logging.StreamHandler and \
+                        h.stream == self.logStream:
+                    found = True
+        if not found:
             logger.addHandler(handler)
 
-        # default level    
+        # default level
         lvl = logging.WARNING
         if self.verbosity >= 5:
             lvl = 0
@@ -413,6 +433,7 @@ class Config(object):
                      "the -w argument on the command line, or by using the "
                      "--tests argument in a configuration file.",
                      DeprecationWarning)
+                warned = True
             self.testNames.append(path)
 
     def default(self):
@@ -560,6 +581,11 @@ class Config(object):
             help="nose's importer will normally evict a package from sys."
             "modules if it sees a package with the same name in a different "
             "location. Set this option to disable that behavior.")
+        parser.add_option(
+            "--no-byte-compile",
+            action="store_false", default=True, dest="byteCompile",
+            help="Prevent nose from byte-compiling the source into .pyc files "
+            "while nose is scanning for and running tests.")
 
         self.plugins.loadPlugins()
         self.pluginOpts(parser)
@@ -580,7 +606,7 @@ class Config(object):
 
     def todict(self):
         return self.__dict__.copy()
-        
+
     def update(self, d):
         self.__dict__.update(d)
 
@@ -590,15 +616,12 @@ class NoOptions(object):
     """
     def __getstate__(self):
         return {}
-    
+
     def __setstate__(self, state):
         pass
 
     def __getnewargs__(self):
         return ()
-    
-    def __getattr__(self, attr):
-        return None
 
     def __bool__(self):
         return False
